]> the.earth.li Git - onak.git/blobdiff - keydb.h
Move CGI sources to their own subdirectory
[onak.git] / keydb.h
diff --git a/keydb.h b/keydb.h
index 29dde7b8dc243a25a9c7aa438d11f06626f24cab..5dcb4364860e10967eb31709fb808e0a94c494d7 100644 (file)
--- a/keydb.h
+++ b/keydb.h
@@ -14,8 +14,7 @@
  * more details.
  *
  * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 51
- * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef __KEYDB_H__
@@ -105,13 +104,14 @@ struct onak_dbctx {
 
 /**
  * @brief Given a keyid delete the key from storage.
* @param keyid The keyid to delete.
  * @param intrans If we're already in a transaction.
  *
  * This function deletes a public key from whatever storage mechanism we
  * are using. Returns 0 if the key existed.
  */
-       int (*delete_key)(struct onak_dbctx *, uint64_t keyid, bool intrans);
+       int (*delete_key)(struct onak_dbctx *, struct openpgp_fingerprint *fp,
+                       bool intrans);
 
 /**
  * @brief Trys to find the keys that contain the supplied text.
@@ -184,15 +184,6 @@ struct onak_dbctx {
        struct ll * (*cached_getkeysigs)(struct onak_dbctx *,
                        uint64_t keyid);
 
-/**
- * @brief Maps a 32 bit key id to a 64 bit one.
- * @param keyid The 32 bit keyid.
- *
- * This function maps a 32 bit key id to the full 64 bit one. It returns the
- * full keyid. If the key isn't found a keyid of 0 is returned.
- */
-       uint64_t (*getfullkeyid)(struct onak_dbctx *, uint64_t keyid);
-
 /**
  * @brief call a function once for each key in the db.
  * @param iterfunc The function to call.
@@ -105,13 +104,14 @@ struct onak_dbctx {
 /**
  * @brief Given a keyid delete the key from storage.
- * @param keyid The keyid to delete.
+ * @param fp The fingerprint of the key to delete.
  * @param intrans If we're already in a transaction.
  *